*** Settings ***
Documentation     A resource file with reusable keywords.

Resource        variables.robot
Library         Selenium2Library
Library         Collections
Library         String

*** Keywords ***

Open Browser for Device
    ${chrome_options}=    Set Chrome Options
    Create Webdriver    ${BROWSER}    chrome_options=${chrome_options}
    #Create Webdriver    ${BROWSER}
    Set Window Size    1280    1000
    Set Selenium Implicit Wait    3
#    Set Selenium Speed    0.2s
    Go to    ${url}
    Device Should Be Open


Set Chrome Options
    [Documentation]    Set Chrome options for headless mode
    ${options}=    Evaluate    sys.modules['selenium.webdriver'].ChromeOptions()    sys, selenium.webdriver
    : FOR    ${option}    IN    @{chrome_arguments}
    \    Call Method    ${options}    add_argument    ${option}
    [Return]    ${options}


Device Should Be Open
    Location Should Contain    http://${SERVER}/


Go to Imaging
    Click Element    css:div#navbtn_clone


Go to Hash-Verify
    Click Element    css:div#navbtn_hash


Create tasks
    Delete Task
    Sleep    1s
    Click Element    css:div#clone_add_btn
    Click Element    css:div#clone_add_btn
    Click Element    css:div#clone_add_btn
    Click Element    css:div#clone_add_btn
    Sleep    1s


Create hashes
    Click Element    css:div#hash_add_btn
    Click Element    css:div#hash_add_btn
    Click Element    css:div#hash_add_btn
    Click Element    css:div#hash_add_btn


Go to Task
    [Arguments]  ${ttask}=4

    Click Element    css:div#clone_tab_${ttask}


Go to Hash
    [Arguments]  ${ttask}=4

    Click Element    css:div#hash_tab_${ttask}


Press OK
    [Arguments]  ${parent_el}=${VARIABLE}

    Click Element    css:div[aria-describedby="${parent_el}"] div[class*="ui-dialog-buttonpane"] button[role="button"]
    #Click Element    //div[@aria-describedby="${parent_el}"]/div[3]/div//button


Press NO
    [Arguments]  ${parent_el}=${VARIABLE}

    #Click Element    css:div[aria-describedby="${parent_el}"] > div > button
    Click Element    css:div[aria-describedby="${parent_el}"] div[class*="ui-dialog-titlebar"] button[role="button"]

Press Continue
    [Arguments]  ${parent_el}=${VARIABLE}

    Click Element    css:div[aria-describedby="${parent_el}"] > div + div + div > div > button + button + button + button > span


Delete Task
    Click Element    css:div#clone_delete_btn
    Sleep    1s
    Press OK    clone_delete_dialog


Delete Hash Task
    Click Element    css:div#hash_delete_btn
    Sleep    1s
    Press OK    hash_delete_dialog


Go to Exit
    Capture Page Screenshot
    [Teardown]    Close Browser


Assert Title
    [Arguments]  ${parent_el}=${VARIABLE}  ${parent_title}=${VARIABLE}

    Element Should Contain    css:div[aria-describedby="${parent_el}"] span.ui-dialog-title    ${parent_title}
    #Element Should Contain    //div[@aria-describedby="${parent_el}"]/div/span    ${parent_title}
    Sleep    1s


Select Task Mode
    [Arguments]  ${mode}=${VARIABLE}

    Click Element    css:div#clone_mode_btn
    Assert Title    clone_mode_dialog    SELECT MODE
    Click Element    css:div#clone_mode_${mode}
    Press OK    clone_mode_dialog


Select Hash Mode
    [Arguments]  ${mode}=${VARIABLE}

    Click Element    //div[@id="hash_mode_btn"]
    Assert Title    hash_mode_dialog    SELECT MODE
    Click Element    //div[@id="hash_mode_${dict_hash_mode['${mode}']}"]
    Press OK    hash_mode_dialog


Select Mode
    [Arguments]  ${mode}=${VARIABLE}

    Click Element    css:div#clone_mode_btn_bottom
    Assert Title    clone_mode_dialog    SELECT MODE
    Click Element    css:div#clone_mode_${dict_mode['${mode}']}
    Press OK    clone_mode_dialog


Select Source
    [Arguments]  ${src_id}=${VARIABLE}
    #${source_tname}=clone_master_select  ${source_dname}=clone_master_dialog
    Run Keyword If  ${two_param_f2f} == 1    Set Test Variable    ${source_tname}  clone_master_source_select
    Run Keyword If  ${two_param_f2f} == 1    Set Test Variable    ${source_dname}  clone_master_source_dialog

    Click Element    css:div#clone_master_btn_bottom
    Assert Title    ${source_dname}    SELECT SOURCE
    Table Cell Should Contain    //table[@id="${source_tname}"]    1    1    DRIVE PORT
    Sleep    13s
    #Click Element    //table[@id="${source_tname}"]//td[@class="col1" and contains(text(),"${src_id}")]
    PageDown Table    ${src_id}    ${source_dname}    ${source_tname}
    Sleep    3s
    Press OK    ${source_dname}
    Run Keyword Unless  ${partition} == 0    Select Source Partition
    Sleep    1s


Select Hash Target
    [Arguments]  ${src_id}=${VARIABLE}

    Set Test Variable    ${source_tname}  clone_target_select
    Set Test Variable    ${source_dname}  clone_target_dialog
    Click Element    //div[@id="hash_target_btn_top"]
    Assert Title    ${source_dname}    SELECT DRIVES
    Table Cell Should Contain    //table[@id="${source_tname}"]    1    1    DRIVE PORT
    PageDown Table    ${src_id}    ${source_dname}    ${source_tname}
    Press OK    ${source_dname}


Select Source Partition
    Assert Title    clone_master_partition_dialog    SELECT PARTITION
    Table Cell Should Contain    //table[@id="clone_master_partition_select"]    1    1    PARTITION
    Sleep    1s
    Click Element    //span[@class="part_num" and contains(text(),"${partition}")]
    Sleep    2s
    Press OK    clone_master_partition_dialog


Select Source Case
    [Arguments]  ${src_id}=${VARIABLE}  ${case_id}=${VARIABLE}

    Click Element    //div[@id="clone_master_btn_top"]
    Assert Title    push_filesystem_dialog    SELECT FILESYSTEM
    Table Cell Should Contain    //table[@id="push_filesystem_select"]    1    1    NAME
    Sleep    21s
    PageDown Table    ${src_id}    push_filesystem_dialog    push_filesystem_select
    Sleep    1s
    Press OK    push_filesystem_dialog
    Assert Title    push_case_dialog    SELECT CASE
    PageDown List    ${case_id}
    Sleep    1s
    Press OK    push_case_dialog


Select Target Case
    [Arguments]  ${src_id}=${VARIABLE}  ${case_id}=${VARIABLE}

    Click Element    //div[@id="hash_target_btn_top"]
    Assert Title    push_filesystem_dialog    SELECT FILESYSTEM
    Table Cell Should Contain    //table[@id="push_filesystem_select"]    1    1    NAME
    PageDown Table    ${src_id}    push_filesystem_dialog    push_filesystem_select
    Sleep    1s
    Press OK    push_filesystem_dialog
    Assert Title    push_case_dialog    SELECT CASE
    PageDown List    ${case_id}
    Sleep    1s
    Press OK    push_case_dialog


PageDown Table
    [Arguments]  ${cell_text}=${VARIABLE}  ${dname}=${VARIABLE}  ${tname}=${VARIABLE}

    ${loop_exit_el}    Get WebElement    //table[@id="${tname}"]//td[@class="col1" and contains(text(),"${cell_text}")]
    :FOR    ${i}    IN RANGE    9
    \    ${loopexitstatus}=  Run Keyword And Return Status  Element Should Be Visible    ${loop_exit_el}
    \    Exit For Loop If    ${loopexitstatus}
    \    Click Element    css:div[aria-describedby="${dname}"] > div + div > div > div > div + div > a.mCSB_buttonDown
    \    Sleep    2s
    Click Element    ${loop_exit_el}


PageDown List
    [Arguments]  ${source_text}=${VARIABLE}

    ${loop_exit_el}    Get WebElement    //*[@id="${source_text}_anchor"]
    :FOR    ${i}    IN RANGE    9
    \    ${loop_exit_status}=  Run Keyword And Return Status  Element Should Be Visible    ${loop_exit_el}
    \    Exit For Loop If    ${loopexitstatus}
    \    Click Element    css:div[aria-describedby="push_case_dialog"] > div + div > div > div > div + div > a.mCSB_buttonDown
    \    Sleep    2s
    Click Element    ${loop_exit_el}


Change Length
    [Arguments]  ${num_blocks}=${VARIABLE}

    Click Element    //div[@id="clone_settings_btn_top"]
    Assert Title    clone_settings_dialog    SELECT SETTINGS
    Click Element    //div[@id="clone_method_block_content"]
    Assert Title    clone_mirror_dialog    MIRROR CLONE ADVANCED SETTINGS
    Click Element    //div[@id="clone_mirror_length_lbas"]
    Sleep    1s
    Set Focus To Element    //input[@id="blocks_val"]
    Clear Element Text    //input[@id="blocks_val"]
    Press Keys    //input[@id="blocks_val"]    ${num_blocks}
    Press OK    blocks_set_dialog
    Press OK    clone_mirror_dialog
    Press OK    clone_settings_dialog


Change Hash Length
    [Arguments]  ${num_blocks}=${VARIABLE}

    Click Element    //div[@id="hash_settings_btn_top"]
    Assert Title    hash_settings_dialog    HASH SETTINGS
    Click Element    //div[@id="hash_lba_btn"]
    Assert Title    hash_lba_dialog    LBA SETTINGS
    Click Element    //div[@id="hash_lba_length_lbas"]
    Sleep    1s
    Set Focus To Element    //input[@id="blocks_val"]
    Clear Element Text    //input[@id="blocks_val"]
    Press Keys    //input[@id="blocks_val"]    ${num_blocks}
    Press OK    blocks_set_dialog
    Press OK    hash_lba_dialog
    Press OK    hash_settings_dialog


Select Image Method Settings
    [Arguments]  ${image_type}=${VARIABLE}

    Click Element    css:div#clone_settings_btn
    Assert Title    clone_settings_dialog    SELECT SETTINGS
    Click Element    //div[@id="clone_file_image_block_content"]
    Assert Title    clone_file_image_dialog    FILE IMAGE METHOD SETTINGS
    Click Element    //div[@id="clone_capture_${dict_image['${image_type}']}"]
    Sleep    1s
    Press OK    clone_file_image_dialog
    Press OK    clone_settings_dialog


Select Segment Size
    [Arguments]  ${seg_size}=${VARIABLE}

    Click Element    //div[@id="clone_settings_btn_top"]
    Assert Title    clone_settings_dialog    SELECT SETTINGS
    Click Element    //div[@id="clone_file_image_block_content"]
    Assert Title    clone_file_image_dialog    FILE IMAGE METHOD SETTINGS

    Click Element    //div[@id="clone_segment_block_content"]
    #Click Element    //div[@id="clone_segment_block"]/div
    Assert Title    clone_segment_dialog    SEGMENT SIZE
    Click Element    //div[@id="clone_segment_${dict_segment['${seg_size}']}"]
    Sleep    1s
    Press OK    clone_segment_dialog
    Press OK    clone_file_image_dialog
    Press OK    clone_settings_dialog


Select Output Segment Size
    [Arguments]  ${seg_size}=${VARIABLE}

    Click Element    //div[@id="clone_settings_btn_top"]
    Assert Title    clone_settings_dialog    SELECT SETTINGS
    Click Element    //div[@id="clone_output_format_block_content"]
    Assert Title    clone_output_format_dialog    OUTPUT FORMAT SETTINGS

    Click Element    //div[@id="clone_output_segment_block_content"]
    Assert Title    clone_segment_dialog    SEGMENT SIZE
    Click Element    //div[@id="clone_segment_${dict_segment['${seg_size}']}"]
    Sleep    1s
    Press OK    clone_segment_dialog
    Press OK    clone_output_format_dialog
    Press OK    clone_settings_dialog


Select Compression
    [Arguments]  ${compr}=${VARIABLE}

    Click Element    //div[@id="clone_settings_btn_top"]
    Assert Title    clone_settings_dialog    SELECT SETTINGS
    Click Element    //div[@id="clone_file_image_block_content"]
    Assert Title    clone_file_image_dialog    FILE IMAGE METHOD SETTINGS

    Click Element    //div[@id="clone_compression_block_content"]
    Assert Title    clone_compression_dialog    COMPRESSION
    Click Element    //div[@id="clone_dco_${dict_compr['${compr}']}"]
    Sleep    1s
    Press OK    clone_compression_dialog
    Press OK    clone_file_image_dialog
    Press OK    clone_settings_dialog


Select Output Compression
    [Arguments]  ${compr}=${VARIABLE}

    Click Element    //div[@id="clone_settings_btn_top"]
    Assert Title    clone_settings_dialog    SELECT SETTINGS
    Click Element    //div[@id="clone_output_format_block_content"]
    Assert Title    clone_output_format_dialog    OUTPUT FORMAT SETTINGS

    Click Element    //div[@id="clone_output_compression_block_content"]
    Assert Title    clone_compression_dialog    COMPRESSION
    Click Element    //div[@id="clone_dco_${dict_compr['${compr}']}"]
    Sleep    1s
    Press OK    clone_compression_dialog
    Press OK    clone_output_format_dialog
    Press OK    clone_settings_dialog


Select Hash Method
    [Arguments]  ${hash_method}=${VARIABLE}    ${verify}=0

    Click Element    //div[@id="clone_settings_btn_top"]
    Assert Title    clone_settings_dialog    SELECT SETTINGS
    Click Element    //div[@id="clone_verif_block_content"]
    Assert Title    clone_verif_dialog    HASH METHOD

    Click Element    //div[@id="clone_hash_${dict_hash['${hash_method}']}"]
    Sleep    1s
    Click Element    //div[@id="clone_verif_${dict_ver['${verify}']}"]
    Sleep    1s
    Press OK    clone_verif_dialog
    Press OK    clone_settings_dialog


Select Hash Settings
    [Arguments]  ${hash_method}=${VARIABLE}
    Click Element    //div[@id="hash_settings_btn_top"]
    Assert Title    hash_settings_dialog    HASH SETTINGS
    Click Element    //div[@id="hash_values_btn_top"]
    Assert Title    hash_values_dialog    HASH VALUES

    Click Element    //div[@id="hash_method_${dict_hash['${hash_method}']}"]
    Sleep    1s
    Press OK    hash_values_dialog
    Press OK    hash_settings_dialog


Select Output Format
    [Arguments]  ${output_format}=${VARIABLE}

    Click Element    //div[@id="clone_settings_btn_top"]
    Assert Title    clone_settings_dialog    SELECT SETTINGS
    Click Element    //div[@id="clone_output_format_block_content"]
    Assert Title    clone_output_format_dialog    OUTPUT FORMAT SETTINGS
    Click Element    //div[@id="clone_output_format_${dict_output['${output_format}']}"]
    Sleep    1s
    Press OK    clone_output_format_dialog
    Press OK    clone_settings_dialog


Select Filter Settings
    [Arguments]  ${path_tree}=${VARIABLE}  ${path_filter}==NaN

    Click Element    //div[@id="clone_settings_btn_top"]
    Assert Title    clone_settings_dialog    SELECT SETTINGS
    Click Element    //div[@id="clone_filter_settings_block_content"]
    Assert Title    clone_filter_settings_dialog    ADVANCED FILTER SETTINGS
    Click Element    //div[@id="clone_path_filter_block"]
    Assert Title    clone_path_filter_dialog    SEARCH PATHS FILTER
    Click Element    //div[@id="clone_files_dirs_block"]
    Assert Title    clone_files_dirs_dialog    FILES / DIRECTORIES
    ${sep}    Set Variable    ${EMPTY}
    @{words}=   Convert To List    ${path_tree}
    :FOR    ${element}    IN    @{words}
    \    Log    ${element}
    \    ${str_one}=    Catenate    SEPARATOR=${sep}    ${str_one}    ${element}
    \    Sleep    1s
    \    PageDown Tree    ${str_one}
    \    ${sep}    Set Variable    /
    Sleep    1s
    Click Element    //*[@id="${str_one}_anchor"]

    Press OK    clone_files_dirs_dialog
    Press OK    clone_path_filter_dialog
    Press OK    clone_filter_settings_dialog
    Press OK    clone_settings_dialog


Select Filter Settings Falcon
    [Arguments]  ${path_tree}=${VARIABLE}  ${path_filter}==NaN

    Click Element    //div[@id="clone_settings_btn_top"]
    Assert Title    clone_settings_dialog    SELECT SETTINGS
#    Click Element    //div[@id="clone_filter_settings_block_content"]
#    Assert Title    clone_filter_settings_dialog    ADVANCED FILTER SETTINGS
#    Click Element    //div[@id="clone_path_filter_block"]
#    Assert Title    clone_path_filter_dialog    SEARCH PATHS FILTER
#    Click Element    //div[@id="clone_files_dirs_block"]
#    Assert Title    clone_files_dirs_dialog    FILES / DIRECTORIES
    Click Element    //div[@id="clone_root_dir_block"]
    Assert Title    clone_root_dir_keyboard_dialog    ROOT DIRECTORY
    Click Element    //div[@id="clone_root_dir_browse"]
    Assert Title    root_dir_browser_dialog    FILE BROWSER

    ${sep}    Set Variable    ${EMPTY}
    @{words}=   Convert To List    ${path_tree}
    :FOR    ${element}    IN    @{words}
    \    Log    ${element}
    \    ${str_one}=    Catenate    SEPARATOR=${sep}    ${str_one}    ${element}
    \    Sleep    2s
    #\    PageDown Tree Falcon    ${str_one}
    \    Click Element    css=:root body[dir=ltr] div > table > tbody td[data-sort-value=partn-1_ntfs]
    \    ${sep}    Set Variable    /
    Sleep    1s
    Click Element    //*[@id="${str_one}_anchor"]

    Press OK    root_dir_browser_dialog
    Press OK    clone_root_dir_keyboard_dialog
    Press OK    clone_settings_dialog


PageDown Tree
    [Arguments]  ${path_target}=${VARIABLE}

    Sleep    4s
    ${loopexitel}    Get WebElement    //*[@id="${path_target}_anchor"]
    :FOR    ${i}    IN RANGE    9
    \    ${loopexitstatus}=  Run Keyword And Return Status  Element Should Be Visible    ${loopexitel}
    \    Exit For Loop If    ${loopexitstatus}
    \    Click Element    css:div[aria-describedby="clone_files_dirs_dialog"] > div + div > div > div > div + div > a.mCSB_buttonDown
    \    Sleep    3s
    Click Element    //*[@id="${path_target}"]/i


PageDown Tree Falcon
    [Arguments]  ${path_target}=${VARIABLE}

    ${loopexitel}    Get WebElement    //strong[contains(text(), '${path_target}')]
    :FOR    ${i}    IN RANGE    9
    \    ${loopexitstatus}=  Run Keyword And Return Status  Element Should Be Visible    ${loope$
    \    Exit For Loop If    ${loopexitstatus}
    \    Click Element    css:div[aria-describedby="clone_files_dirs_dialog"] > div + div > div $
    \    Sleep    3s
    Click Element    //*[@id="${path_target}"]/i
    #Capture Page Screenshot


Select Drive Destination
    [Arguments]  ${trgt_id}=${VARIABLE}  ${dest_tname}=clone_target_select

    Click Element    //div[@id="clone_target_btn"]
    Assert Title    clone_target_dialog    SELECT DESTINATIONS
    Table Cell Should Contain    //table[@id="${dest_tname}"]    1    1    DRIVE PORT
    Sleep    21s
    Click Element    //table[@id="${dest_tname}"]//td[@class="col1" and contains(text(),"${trgt_id}")]
    Sleep    1s
    Capture Page Screenshot
    Press OK    clone_target_dialog
    ${target}    Get Text    //div[@id="clone_target_btn_bottom"]
    Sleep    1s

Select File Destination
    [Arguments]  ${trgt_id}=${VARIABLE}  ${dest_tname}=clone_target_repo_select

    Click Element    css:div#clone_target_btn_bottom
    Assert Title    clone_target_repo_dialog    SELECT REPOSITORY
    Table Cell Should Contain    //table[@id="${dest_tname}"]    1    1    REPOSITORY
    Sleep    13s
    Click Element    //table[@id='clone_target_repo_select']//*[contains(text(),"${trgt_id}")]
    Sleep    1s
    Press OK    clone_target_repo_dialog
    ${target}    Get Text    //div[@id="clone_target_btn_bottom"]
    Sleep    1s


Start Task
    [Arguments]  ${num_tasks}=1

    Sleep    2s
    Capture Page Screenshot
    ${start_btn}    Get WebElement    css:div#clone_start_btn
    Click Element    ${start_btn}
    Run Keyword Unless  ${norun_flag}==1    Run Keywords    Press OK    clone_start_dialog    AND    Check Dialog Task
    Run Keyword If  ${norun_flag}==1    Run Keywords    Press NO    clone_start_dialog    AND    Return From Keyword    ${1}
    Sleep    1s
    :FOR    ${i}    IN RANGE    6400
    \    ${loopexitstatus}=  Run Keyword And Return Status  Element Should Contain    css:div#clone_progressbar_info     COMPLETED
    \    ${loopexiterror}=  Run Keyword And Return Status  Element Should Contain    css:div#clone_progressbar_info     ERROR
    \    Exit For Loop If    ${loopexitstatus}
    \    Exit For Loop If    ${loopexiterror}
    \    Sleep    20s
    Sleep    1s
    Run Keyword And Continue On Failure    Element Should Contain    css:div#clone_progressbar_info     COMPLETED
    Capture Page Screenshot


Check Dialog Task
    Sleep    1s
    ${parlltasks}=  Run Keyword And Return Status  Element Should Be Visible    css:div[aria-describedby="clone_parallel_task_dialog"] > div > span
    Run Keyword If  ${parlltasks}==1    Press OK    clone_parallel_task_dialog
    ${hdd4ktask}=  Run Keyword And Return Status  Element Should Be Visible    css:div[aria-describedby="prompt_message_dialog"] > div + div
    Run Keyword If  ${hdd4ktask}==1    Press Continue    prompt_message_dialog


Delete All Hash Tasks
    Go to Hash-Verify
    Delete Hash Task
    Delete Hash Task
    Delete Hash Task
    Delete Hash Task
    Delete Hash Task


Result Should Contain Text
    Wait Until Page Contains    IMAGING    5 s


Open Browser For Empty Page
    [Arguments]
    Open Browser    about:blank
    Maximize Browser Window
